@@ -45,14 +45,10 @@ my $bless_exception
 
     my ( $method ) = @_;
 
-    print STDERT "\nBreaking up method: '$method'\n";
-
     my ( $pack, $name )
     = $method =~ m{^ ( .+ ) :: ( \w+ ) $}x
     or die "Bogus Sub::ForceEval: no package and method in '$method'";
 
-    print STDERT "\nFound: '$pack', '$name'\n";
-
     my $sub = $pack->can( $name )
     or croak "Bogus Sub::ForceEval: '$pack' cannot '$name'";
 
@@ -102,8 +98,6 @@ sub UNIVERSAL::ForceEval :ATTR(CODE)
 {
   my ( undef, $install, $wrapped, undef, $method ) = @_;
 
-  print STDERR "\nWrapping with method: '$method'\n";
-
   my $pkg   = *{$install}{PACKAGE};
 
   my $name  = join '::', $pkg, *{$install}{NAME};
